%global base_name chain
%global short_name commons-%{base_name}
Name:          apache-commons-chain
Version:       1.2
Release:       %mkrel 15
Group:         Development/Java
Summary:       An implementation of the GoF Chain of Responsibility pattern
License:       ASL 2.0
URL:           http://commons.apache.org/%{base_name}/
Source0:       ftp://ftp.gbnet.net/pub/apache/dist/commons/%{base_name}/source/%{short_name}-%{version}-src.tar.gz
# javax.servlet 3.1 api support
Patch0:        %{name}-%{version}-tests-servlet31.patch
# javax.portlet 2.0 api support
Patch1:        %{name}-%{version}-portlet20.patch

BuildRequires: maven-local
BuildRequires: mvn(commons-beanutils:commons-beanutils)
BuildRequires: mvn(commons-digester:commons-digester)
BuildRequires: mvn(commons-logging:commons-logging)
BuildRequires: mvn(javax.portlet:portlet-api)
BuildRequires: mvn(javax.servlet:javax.servlet-api)
BuildRequires: mvn(junit:junit)
BuildRequires: mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires: mvn(org.apache.commons:commons-parent:pom:)
BuildRequires: mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires: mvn(org.apache.maven.plugins:maven-remote-resources-plugin)
BuildRequires: mvn(org.apache.maven.plugins:maven-site-plugin)
BuildRequires: mvn(org.codehaus.mojo:buildnumber-maven-plugin)
BuildRequires: mvn(org.jboss.spec.javax.faces:jboss-jsf-api_2.1_spec)

BuildArch:     noarch

%description
A popular technique for organizing the execution of complex
processing flows is the "Chain of Responsibility" pattern, as
described (among many other places) in the classic "Gang of Four"
design patterns book. Although the fundamental API contracts
required to implement this design pattern are extremely simple,
it is useful to have a base API that facilitates using the pattern,
and (more importantly) encouraging composition of command
implementations from multiple diverse sources.
Towards that end, the Chain API models a computation as a series
of "commands" that can be combined into a "chain". The API for a
command consists of a single method (execute()), which is passed
a "context" parameter containing the dynamic state of the
computation, and whose return value is a boolean that determines
whether or not processing for the current chain has been completed
(true), or whether processing should be delegated to the next
command in the chain (false).

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n %{short_name}-%{version}-src
find . -name '*.class' -delete
find . -name '*.jar' -delete

perl -pi -e 's/\r$//g;' *.txt

%patch0 -p1
%patch1 -p0
# Failed tests:   testDefaut(org.apache.commons.chain.config.ConfigParserTestCase):
# Correct command count expected:<17> but was:<19>
rm -r src/test/org/apache/commons/chain/config/ConfigParserTestCase.java

%pom_remove_dep :myfaces-api
%pom_add_dep org.jboss.spec.javax.faces:jboss-jsf-api_2.1_spec
# Force servlet 3.1 apis
%pom_xpath_set "pom:dependency[pom:groupId = 'javax.servlet' ]/pom:artifactId" javax.servlet-api
%pom_xpath_set "pom:dependency[pom:groupId = 'javax.servlet' ]/pom:version" 3.1.0

%mvn_file :%{short_name} %{name}
%mvn_file :%{short_name} %{short_name}

%build

%mvn_build -- -Dmaven.compile.source=1.6 -Dmaven.compile.target=1.6

%install
%mvn_install

%files -f .mfiles
%doc RELEASE-NOTES.txt
%license LICENSE.txt NOTICE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt NOTICE.txt



%changelog
* Thu May 18 2017 neoclust <neoclust> 1.2-15.mga6
+ Revision: 1103024
- Rebuild against new apache-parent

* Wed Mar 02 2016 neoclust <neoclust> 1.2-14.mga6
+ Revision: 982349
- Second rebuild of the java stack

* Sun Feb 21 2016 neoclust <neoclust> 1.2-13.mga6
+ Revision: 975426
- First rebuild of the java stack
- sync package apache-commons-chain with fedora

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Thu Dec 25 2014 pterjan <pterjan> 1.2-11.mga5
+ Revision: 805810
- Clean rebuild

  + dmorgan <dmorgan>
    - Restore from Obsolete

  + sander85 <sander85>
    - Depends on broken java stack

* Wed Oct 15 2014 umeabot <umeabot> 1.2-9.mga5
+ Revision: 739194
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.2-8.mga5
+ Revision: 677789
- Mageia 5 Mass Rebuild

* Tue Oct 22 2013 umeabot <umeabot> 1.2-7.mga4
+ Revision: 545557
- Mageia 4 Mass Rebuild

* Wed Oct 16 2013 dmorgan <dmorgan> 1.2-6.mga4
+ Revision: 501414
- Build with xmvn

* Sat Jul 13 2013 dmorgan <dmorgan> 1.2-5.mga4
+ Revision: 453843
- added missing BR surefire-provider-junit
- Rebuild against java7

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jun 22 2012 dmorgan <dmorgan> 1.2-2.mga3
+ Revision: 262581
- Add demap file
- imported package apache-commons-chain


* Tue Jun 05 2012 gil cattaneo <puntogil@libero.it> 1.2-2
- NOTICE.txt file installed along with javadoc package

* Thu Apr 19 2012 gil cattaneo <puntogil@libero.it> 1.2-1
- initial rpm

